;+
;NAME:
;	dtcf_pc_hxs
;PURPOSE:        
;       Deadtime correction factor for HXS-PC1 and PC2.  The correction
;       is not exact when  the deadtime-corrected count of total PC exceeds
;       about 100,000 counts/sec. It is due to instrument limitation.
;CALLING SEQUENCE:
;	subs = dtcf_pc_hxs(float)
;INPUTS:
;	float - (HXS-PC1 + HXS-PC2) [counts/sec]
;HISTORY:
;	26-Jun-93  (K.Suga) First written.
;       2-Aug-93 Updated by T.Hiraoka  ;Expression can be an array.
;       25-nov-93 Revised by J.Sato, K.Morimoto and M.Yoshimori
;-
;
;        << HXS-PC1, HXS-PC2 dead time = 7.83 micro sec.>>
function dtcf_pc_hxs,ht

ht = float( ht )

dtcf = 0.99592 + 1.3996e-5*ht - 1.2299e-9*ht^2 $
           + 1.0011e-13*ht^3 - 3.0092e-18*ht^4 + 3.3348e-23*ht^5

if ( total( where( ht ge 45000.) ) ne -1 ) then begin

dtcf( where( ht ge 45000.) ) = $ 
  2.0821 + 2.5447e-4*(ht(where(ht ge 45000.))-45000.) $
         - 6.1466e-7*(ht(where(ht ge 45000.))-45000.)^2 $
         + 1.0749e-9*(ht(where(ht ge 45000.))-45000.)^3 $
         - 7.1942e-13*(ht(where(ht ge 45000.))-45000.)^4 $
         + 1.7084e-16*(ht(where(ht ge 45000.))-45000.)^5

endif

return,dtcf
end
